@@ -24,15 +24,22 @@ async def async_main():
     graph.add_precedence(time, printer)
 
     # Set the time after 1 second
-    timer_1 = aiocells.source(functools.partial(aiocells.timer, 1, time))
+    timer_1 = functools.partial(aiocells.timer, 1, time)
     graph.add_precedence(timer_1, time)
 
     # Set the time after 3 seconds
-    timer_3 = aiocells.source(functools.partial(aiocells.timer, 3, time))
+    timer_3 = functools.partial(aiocells.timer, 3, time)
     graph.add_precedence(timer_3, time)
 
+    print()
+    print("Demo will complete in 10 iterations. Ctrl-C to cancel.")
+    print()
+
+    iteration_count = 0
     while await aiocells.compute_flow(graph):
-        pass
+        iteration_count += 1
+        if iteration_count > 10:
+            await aiocells.cancel_flow(graph)
 
 
 def main():
