@@ -49,7 +49,10 @@ async def compute_flow(graph):
             return len(flow_state.input_tasks)
 
         # Wait for at least one input node to complete
-        logger.debug("Waiting for input tasks")
+        logger.debug(
+            "Waiting for input tasks, input_tasks=%s",
+            basic.task_names(flow_state.input_tasks)
+        )
         completed_input_tasks, flow_state.input_tasks = await asyncio.wait(
             flow_state.input_tasks,
             return_when=asyncio.FIRST_COMPLETED
@@ -95,8 +98,7 @@ async def compute_flow(graph):
         logger.debug("Caught asyncio.CancelledError in %s", graph.name)
         # Don't reraise - this is an expected error when cancelling the
         # flow with `cancel_flow`
-    except Exception as e:
-        logger.debug("Caught exception %s in %s", e, graph.name)
+    except Exception:
         await aio.cancel_tasks(flow_state.input_tasks)
         # Reraise - this is an unexpected exception
         raise
